==> zzyj-outputvalcount-api-3.0.0-20221025.235614-115-sources.jar: com/ejianc/business/outputvalcount/vo/MonthlyStatisticsVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 月度产值统计
 * 
 * @author generator
 * 
 */
public class MonthlyStatisticsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String projectName; // 工程名称
    private Long lbId; // 工程类别id
    private String lbName; // 工程类别
    private Long jglxId; // 结构类型id
    private String jglxName; // 结构类型
    private BigDecimal zje; // 总金额
    private String zmj; // 总面积
    private String address; // 工程所在地
    private Integer zcrs; // 在场从业人数
    private Integer year; // 年份
    private Integer month; // 月份
    private Long gcztId; // 工程状态id
    private String gcztName; // 工程状态
    private BigDecimal bywccz; // 本月完成产值
    private BigDecimal bnwccz; // 自年初累计完成产值
    private BigDecimal kgwccz; // 自开工累计完成产值
    private String description; // 形象进度描述
    private Long projectId; // 工程名称id
    private Long measureType; // 工程度量方式
    private Long buildUnitId; // 工程父id
    private String bildUnitName; // 施工单位
    private BigDecimal zlje; // 暂列金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date statDate; // 产值统计日期
    private Long projectDepartmentId; // 项目组织id

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMeasureType() {
        return measureType;
    }
    @ReferDeserialTransfer
    public void setMeasureType(Long measureType) {
        this.measureType = measureType;
    }

    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getLbId() {
        return lbId;
    }
    @ReferDeserialTransfer
    public void setLbId(Long lbId) {
        this.lbId = lbId;
    }
    public String getLbName() {
        return lbName;
    }

    public void setLbName(String lbName) {
        this.lbName = lbName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getJglxId() {
        return jglxId;
    }
    @ReferDeserialTransfer
    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }
    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
    public String getZmj() {
        return zmj;
    }

    public void setZmj(String zmj) {
        this.zmj = zmj;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Integer getZcrs() {
        return zcrs;
    }

    public void setZcrs(Integer zcrs) {
        this.zcrs = zcrs;
    }
    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public Long getGcztId() {
        return gcztId;
    }

    public void setGcztId(Long gcztId) {
        this.gcztId = gcztId;
    }
    public String getGcztName() {
        return gcztName;
    }

    public void setGcztName(String gcztName) {
        this.gcztName = gcztName;
    }
    public BigDecimal getBywccz() {
        return bywccz;
    }

    public void setBywccz(BigDecimal bywccz) {
        this.bywccz = bywccz;
    }
    public BigDecimal getBnwccz() {
        return bnwccz;
    }

    public void setBnwccz(BigDecimal bnwccz) {
        this.bnwccz = bnwccz;
    }
    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }


    public Long getBuildUnitId() {
        return buildUnitId;
    }

    public void setBuildUnitId(Long buildUnitId) {
        this.buildUnitId = buildUnitId;
    }

    public String getBildUnitName() {
        return bildUnitName;
    }

    public void setBildUnitName(String bildUnitName) {
        this.bildUnitName = bildUnitName;
    }

    public BigDecimal getZlje() {
        return zlje;
    }

    public void setZlje(BigDecimal zlje) {
        this.zlje = zlje;
    }

    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }
}

==> zzyj-outputvalcount-api-3.0.0-20230919.103817-254-sources.jar: com/ejianc/business/outputvalcount/vo/MonthlyStatisticsVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 月度产值统计
 * 
 * @author generator
 * 
 */
public class MonthlyStatisticsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String projectName; // 工程名称
    private Long lbId; // 工程类别id
    private String lbName; // 工程类别
    private Long jglxId; // 结构类型id
    private String jglxName; // 结构类型
    private BigDecimal zje; // 总金额
    private String zmj; // 总面积
    private String address; // 工程所在地
    private Integer zcrs; // 在场从业人数
    private Integer year; // 年份
    private Integer month; // 月份
    private Long gcztId; // 工程状态id
    private String gcztName; // 工程状态
    private BigDecimal bywccz; // 本月完成产值
    private BigDecimal bnwccz; // 自年初累计完成产值
    private BigDecimal kgwccz; // 自开工累计完成产值
    private String description; // 形象进度描述
    private Long projectId; // 工程名称id
    private Long measureType; // 工程度量方式
    private Long buildUnitId; // 工程父id
    private String bildUnitName; // 施工单位
    private BigDecimal zlje; // 暂列金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date statDate; // 产值统计日期
    private Long projectDepartmentId; // 项目组织id
    private Integer yearPlan; // 年份
    private Integer monthPlan; // 月份
    private BigDecimal byjhwcczPlan; // 本月计划完成产值
    private String descriptionPlan; // 形象进度描述
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date statDatePlan; // 产值统计日期


    public Integer getYearPlan() {
        return yearPlan;
    }

    public void setYearPlan(Integer yearPlan) {
        this.yearPlan = yearPlan;
    }

    public Integer getMonthPlan() {
        return monthPlan;
    }

    public void setMonthPlan(Integer monthPlan) {
        this.monthPlan = monthPlan;
    }

    public BigDecimal getByjhwcczPlan() {
        return byjhwcczPlan;
    }

    public void setByjhwcczPlan(BigDecimal byjhwcczPlan) {
        this.byjhwcczPlan = byjhwcczPlan;
    }

    public String getDescriptionPlan() {
        return descriptionPlan;
    }

    public void setDescriptionPlan(String descriptionPlan) {
        this.descriptionPlan = descriptionPlan;
    }

    public Date getStatDatePlan() {
        return statDatePlan;
    }

    public void setStatDatePlan(Date statDatePlan) {
        this.statDatePlan = statDatePlan;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMeasureType() {
        return measureType;
    }
    @ReferDeserialTransfer
    public void setMeasureType(Long measureType) {
        this.measureType = measureType;
    }

    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getLbId() {
        return lbId;
    }
    @ReferDeserialTransfer
    public void setLbId(Long lbId) {
        this.lbId = lbId;
    }
    public String getLbName() {
        return lbName;
    }

    public void setLbName(String lbName) {
        this.lbName = lbName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getJglxId() {
        return jglxId;
    }
    @ReferDeserialTransfer
    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }
    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
    public String getZmj() {
        return zmj;
    }

    public void setZmj(String zmj) {
        this.zmj = zmj;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Integer getZcrs() {
        return zcrs;
    }

    public void setZcrs(Integer zcrs) {
        this.zcrs = zcrs;
    }
    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public Long getGcztId() {
        return gcztId;
    }

    public void setGcztId(Long gcztId) {
        this.gcztId = gcztId;
    }
    public String getGcztName() {
        return gcztName;
    }

    public void setGcztName(String gcztName) {
        this.gcztName = gcztName;
    }
    public BigDecimal getBywccz() {
        return bywccz;
    }

    public void setBywccz(BigDecimal bywccz) {
        this.bywccz = bywccz;
    }
    public BigDecimal getBnwccz() {
        return bnwccz;
    }

    public void setBnwccz(BigDecimal bnwccz) {
        this.bnwccz = bnwccz;
    }
    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }


    public Long getBuildUnitId() {
        return buildUnitId;
    }

    public void setBuildUnitId(Long buildUnitId) {
        this.buildUnitId = buildUnitId;
    }

    public String getBildUnitName() {
        return bildUnitName;
    }

    public void setBildUnitName(String bildUnitName) {
        this.bildUnitName = bildUnitName;
    }

    public BigDecimal getZlje() {
        return zlje;
    }

    public void setZlje(BigDecimal zlje) {
        this.zlje = zlje;
    }

    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }
}
